@@ -14,6 +14,8 @@ import jinja2 as jinja
 from jinja2.exceptions import TemplateNotFound
 from sqlalchemybwc import db as sabwc_db
 from webgrid import BaseGrid
+from webgrid.extensions import gettext
+from webgrid.renderers import render_html_attributes
 
 
 class WebGrid(object):
@@ -23,8 +25,11 @@ class WebGrid(object):
         self.init_db(db or sabwc_db)
         self.component = component
         ag.tplengine.env.filters['wg_safe'] = content_filter
+        ag.tplengine.env.filters['wg_attributes'] = render_html_attributes
+        ag.tplengine.env.filters['wg_gettext'] = gettext
         self.jinja_environment = jinja.Environment(
             loader=self.jinja_loader,
+            finalize=lambda x: x if x is not None else '',
             autoescape=True
         )
 
